UserParameter=user.discovery.docker-service,sudo -u {{ hive_safe_admin }} sh -c "export DOCKER_HOST={{ groups['hives'] | intersect(groups[hive_stage]) | first }}:2376;export DOCKER_TLS_VERIFY=1;{{ hive_home_dir }}/docker/bin/python {{ hive_home_dir }}/docker-service.py --discover"
UserParameter=docker-service-uptime[*],sudo -u {{ hive_safe_admin }} sh -c "export DOCKER_HOST={{ groups['hives'] | intersect(groups[hive_stage]) | first }}:2376;export DOCKER_TLS_VERIFY=1;{{ hive_home_dir }}/docker/bin/python {{ hive_home_dir }}/docker-service.py --uptime $1"
UserParameter=docker-service-replicas[*],sudo -u {{ hive_safe_admin }} sh -c "export DOCKER_HOST={{ groups['hives'] | intersect(groups[hive_stage]) | first }}:2376;export DOCKER_TLS_VERIFY=1;{{ hive_home_dir }}/docker/bin/python {{ hive_home_dir }}/docker-service.py --replicas $1"
